@@ -114,7 +114,7 @@ n_retains=-1, autoload=False)
         filename (str): Name of the file into which the object is serialized.
             It can be a format string, where the manager object is passed to
             the :meth:`str.format` method. For example,
-            ``'snapshot_{.updater.iteration}'`` is converted to
+            ``'snapshot_{.iteration}'`` is converted to
             ``'snapshot_10000'`` at the 10,000th iteration.
         savefun: Function to save the object. It takes two arguments: the
             output file path and the object to serialize.
@@ -162,7 +162,7 @@ n_retains=-1, autoload=False)
 
 
 def snapshot(savefun=None,
-             filename='snapshot_iter_{.updater.iteration}',
+             filename='snapshot_iter_{.iteration}',
              *,
              target=None,
              condition=None,
@@ -319,7 +319,7 @@ class _Snapshot(extension.Extension):
 
     def __init__(
             self, target=None, condition=None, writer=None,
-            filename='snapshot_iter_{.updater.iteration}',
+            filename='snapshot_iter_{.iteration}',
             snapshot_on_error=False, n_retains=-1, autoload=False,
             savefun=None,
             transform_models=None, autoload_transform_models=None):
@@ -341,18 +341,16 @@ class _Snapshot(extension.Extension):
         outdir = manager.out
         writer = manager.writer if self.writer is None else self.writer
         self.writer = writer
+        loaded_fn = None
         if self.autoload:
             # If ``autoload`` is on, this code scans the ``outdir``
             # for potential snapshot files by matching the file names
             # from ``filename`` format, picks up the latest one in
             # terms of mtime, and tries to load it it the target or
             # manager.
-            filename = _find_latest_snapshot(self.filename, outdir, writer.fs)
-            if filename is None:
-                print('No snapshot file that matches {} was found'
-                      .format(self.filename))
-            else:
-                snapshot_file = writer.fs.open(os.path.join(outdir, filename))
+            loaded_fn = _find_latest_snapshot(self.filename, outdir, writer.fs)
+            if loaded_fn:
+                snapshot_file = writer.fs.open(os.path.join(outdir, loaded_fn))
                 # As described above (at ``autoload`` option),
                 # snapshot files to be autoloaded must be saved by
                 # ``save_npz`` . In order to support general format,
@@ -387,6 +385,8 @@ class _Snapshot(extension.Extension):
 
             writer._add_cleanup_hook(_cleanup)
 
+        return loaded_fn
+
     def on_error(self, manager, exc, tb):
         super().on_error(manager, exc, tb)
         if self._snapshot_on_error:
@@ -445,7 +445,7 @@ class _DistributedSnapshot(_Snapshot):
 
     def __init__(
             self, target=None, condition=None, writer=None,
-            filename='snapshot_iter_{.updater.iteration}',
+            filename='snapshot_iter_{.iteration}',
             snapshot_on_error=False, n_retains=-1, autoload=False,
             saver_rank=0, savefun=None, transform_models=None,
             autoload_transform_models=None):
@@ -454,8 +454,12 @@ class _DistributedSnapshot(_Snapshot):
                          autoload, savefun, transform_models,
                          autoload_transform_models)
         # To support distributed snapshots
+        if not torch.distributed.is_initialized():
+            raise RuntimeError('The Distributed Snapshot extension',
+                               ' requires torch.distributed to be initialized')
         self._saver_rank = saver_rank
-        self._size, self._rank, self._local_rank = _get_ranks_from_env()
+        self._size = torch.distributed.get_world_size()
+        self._rank = torch.distributed.get_rank()
         if not (0 <= saver_rank < self._size):
             raise ValueError('Distributed snapshot requires a saver rank'
                              ' in the range [0-{})'.format(self._size))
@@ -468,21 +472,3 @@ class _DistributedSnapshot(_Snapshot):
                 self._make_snapshot(trainer)
             if self._size > 1:
                 torch.distributed.barrier()
-
-
-def _get_ranks_from_env():
-    if 'OMPI_COMM_WORLD_SIZE' in os.environ:
-        # We are running Open MPI
-        comm_world_size = int(os.environ["OMPI_COMM_WORLD_SIZE"])
-        comm_rank = int(os.environ["OMPI_COMM_WORLD_RANK"])
-        comm_local_rank = int(os.environ['OMPI_COMM_WORLD_LOCAL_RANK'])
-    elif 'MV2_COMM_WORLD_SIZE' in os.environ:
-        comm_world_size = int(os.environ['MV2_COMM_WORLD_SIZE'])
-        comm_rank = int(os.environ['MV2_COMM_WORLD_RANK'])
-        comm_local_rank = int(os.environ['MV2_COMM_WORLD_LOCAL_RANK'])
-    else:
-        comm_world_size = 1
-        comm_rank = 0
-        comm_local_rank = 0
-
-    return comm_world_size, comm_rank, comm_local_rank
