@@ -3,6 +3,7 @@ import copy
 import contextlib
 import os
 import time
+import warnings
 
 import torch
 
@@ -134,6 +135,18 @@ class _BaseExtensionsManager:
         else:
             return self._out
 
+    @property
+    def updater(self):
+        warnings.warn(
+            'The `updater` attribute has been deprecated in v0.3.0.'
+            ' Use `iteration`, `epoch`, and `epoch_detail` attributes in'
+            ' `ExtensionsManager` instead of attributes under `updater`.'
+            ' You may also need to update the filename template specified to'
+            ' snapshot extensions (e.g., from '
+            '`snapshot_iter_{.updater.iteration}` to'
+            ' `snapshot_iter_{.iteration}`).', DeprecationWarning)
+        return self
+
     def _prepare_for_training(self, start_iteration, iters_per_epoch):
         self.iteration = start_iteration
         self._iters_per_epoch = iters_per_epoch
@@ -431,13 +444,13 @@ class IgniteExtensionsManager(_BaseExtensionsManager):
 
         @self.engine.on(Events.STARTED)
         def set_training_started(engine):
+            self.start_extensions()
             start_iteration = self._start_iteration
             self.engine.state.iteration = self._start_iteration
             self.engine.state.epoch = self._start_epoch
             self._start_time = _get_time()
             iters_per_epoch = len(engine.state.dataloader)
             self._prepare_for_training(start_iteration, iters_per_epoch)
-            self.start_extensions()
 
             # Make all the next
             # handlers to be executed after user defined ones
